#!/usr/bin/env python3
import os
import subprocess
from pathlib import Path

def convert_images():
    # Usar el directorio actual
    source_dir = Path.cwd()

    # Crear directorio de salida en el directorio actual
    output_dir = source_dir / "converted"
    output_dir.mkdir(exist_ok=True)

    # Buscar archivos jpg
    jpg_files = list(source_dir.glob('*.jpg'))

    if not jpg_files:
        print("No se encontraron archivos JPG en el directorio actual.")
        return

    print(f"Se encontraron {len(jpg_files)} archivos JPG para convertir.")

    # Convertir cada imagen
    for jpg_file in jpg_files:
        output_path = output_dir / f"{jpg_file.stem}.png"

        # Comando de conversión con ImageMagick
        command = [
            "convert",
            str(jpg_file),              # Archivo de entrada
            "-resize", "1280x768>",     # Redimensionar, manteniendo proporción
            "-format", "png",            # Convertir a PNG
            str(output_path)             # Archivo de salida
        ]

        try:
            subprocess.run(command, check=True)
            print(f"Convertido: {jpg_file.name} → {output_path.name}")
        except subprocess.CalledProcessError as e:
            print(f"Error al convertir {jpg_file.name}: {e}")

    print("Conversión completada!")

# Ejecutar la función
convert_images()
