
# Documentación: Ocore y Oggui


## Escenario

Queremos dar de alta un ordenador en el sistema y configurarlo para que pueda arrancar mediante PXE en una subred nueva. Este es el escenario:

- **Ordenador**:
  - MAC Address: `00:50:56:1e:9f:11`
  - Nombre: `pc11`
  - Dirección IP: `192.168.3.11`

- **Subred**:
  - Dirección: `192.168.3.0`
  - Máscara de red: `255.255.255.0`

- **Servidor de arranque**:
  - `next-server`: `172.17.8.37` (componente **ogboot** que aloja los ficheros de arranque)
  - Fichero de arranque: `undionly.kpxe`

El objetivo es crear la subred `192.168.2.0/24`, añadir el ordenador `pc11` a esta subred con la IP `192.168.3.11` y crear el fichero de arrnque personalizado a `pc11` a partir de la plantilla PXE `ogLive`.

## Dar de alta ordenador


###  Crear una Unidad Organizativa (Aula)

1. En la pantalla de **Administrar grupos**, haz clic en **Nueva Unidad Organizativa**.
2. En el formulario:
   - Selecciona el **Tipo** como `Aula`.
   - Asigna un **Nombre** al aula, como `Aula Test`.
   - Elige una **Unidad Organizativa Padre**, por ejemplo, `Grupos de aulas 1`.
3. Haz clic en el botón **Siguiente**.

![Menú de centros](../../assets/images/screenshots/menu_centers.png "Menú de centros")

![Crear aula](../../assets/images/screenshots/create-classroom.png "Crear aula")


4. En el siguiente paso del formulario de la Unidad Organizativa, configura los parámetros de red. Estos parámetros serán usados mas adelante como parámetros del Kernel cuando creemos los ficheros de arranque de los PCs que estén en esa aula:
   - **Máscara de Red**: Configura la máscara de subred, como `255.255.255.0`.
   - **Router**: Especifica la puerta de enlace predeterminada de la subred (por ejemplo, `192.168.2.1`).
5. Haz clic en **Añadir** para crear la unidad organizativa.

![Configuración de red del aula](../../assets/images/screenshots/create-classroom-network-configuration.png "Configuración de red del aula")


###  Añadir un Nuevo Ordenador

1. En la pantalla de **Administrar grupos**, haz clic en **Nuevo Cliente**.
2. Completa los siguientes campos:
   - **Padre**: Selecciona la Unidad Organizativa creada anteriormente (por ejemplo, `Aula Test`).
   - **Nombre**: Nombre del ordenador `pc11`.
   - **MAC**: Dirección MAC del cliente `00:50:56:1e:8f:11`.
   - **Dirección IP**: IP en la subred configurada `192.168.2.11`.
   - **Plantilla PXE**: Selecciona la plantilla PXE asociada `ogLive` para el arranque por Oglive.
   - **Interfaz de red**: Interfaz de red del cliente (por ejemplo, `Eth0`).
   - **Controlador de red**: por ejemplo, `Generic`.
3. Haz clic en **Añadir** para guardar el ordenador.


![Crear un ordenador](../../assets/images/screenshots/create_pc.png "Crear un ordenador")



## **Crear una Nueva Subred**

El objetivo es crear una subred en el sistema y sincronizarla con el componente **ogdhcp**, que utiliza Kea DHCP para gestionar las configuraciones de red.


### **Crear la Subred**

1. Ve a la sección **Administrar Subredes**.
2. Haz clic en el botón **Añadir Subred**.
3. En el formulario de creación de subred, completa los siguientes campos:
   - **Nombre**: Asigna un nombre identificativo `Subred test`.
   - **Netmask**: Especifica la máscara de subred  `255.255.255.0`.
   - **Dirección IP**: Configura la dirección base de la subred  `192.168.3.0`.
   - **Next Server**: Ingresa la IP del servidor de arranque `172.17.8.37`.
   - **Boot File Name**: Establece el nombre del archivo de arranque PXE `undionly.kpxe`.
4. Click en **Guardar** para crear la subred en la base de datos del sistema.

![Crear una subred](../../assets/images/screenshots/create_subnet.png "Crear una subred")

Una vez creada, la subred aparecerá en la lista con el estado de **No sincronizada**. Esto indica que la subred se ha registrado en la base de datos, pero aún no se ha dado de alta en el servicio Kea DHCP.

![Subred creada sin sincronizar](../../assets/images/screenshots/created_subnet_no_sync.png "Subred creada sin sincronizar")

---

### **Sincronizar la Subred con Kea DHCP**

1. En la lista de subredes, localiza la nueva subred.
2. Haz clic en el botón de acciones (icono de menú) y selecciona **Crear en og-dhcp**.
3. Esto enviará la configuración de la subred al componente `ogdhcp`, que actualizará el servicio **Kea DHCP**.

![Sincronizar subred](../../assets/images/screenshots/sync_subnet.png "Sincronizar subred")

---

### Subred Sincronizada

Una vez sincronizada, la subred aparecerá con el estado de **Sincronizada** en la lista (tendrá un icono ✔️). Esto indica que la configuración se ha aplicado correctamente en el servicio Kea DHCP.


Puedes ver la configuración que se ha creado en kea dhcp pulsando **Información en servidor ogDHCP** (arriba de todo) y pulsando **Ver informacion**


![Subred KEA](../../assets/images/screenshots/subnet_kea.png "Subred KEA")



## **Añadir Cliente a una Subred**

El objetivo es agregar un PC a una subred específica que ya esté registrada y sincronizada con el componente **ogdhcp**.


### **Añadir cliente a la Subred**

1. En la lista de subredes, busca la subred a la que deseas añadir el cliente `192.168.3.0`.
2. Verifica que la subred esté **Sincronizada** (icono de estado con un ✔️). Si no está sincronizada, realiza el proceso de sincronización previamente.


3. Haz clic en el botón de acciones (icono de menú) para la subred seleccionada.
4. En el menú desplegable, selecciona **Añadir cliente**.

![Subred sincronizada](../../assets/images/screenshots/synced_subnet.png "Subred sincronizada")

5. En el formulario:
   - Busca el nombre del cliente `pc11`.
   - Verifica que el cliente aparece en la lista de **Clientes seleccionados**.
6. Click en el botón **Añadir**

![Añadir cliente a la subred](../../assets/images/screenshots/add_client_to_subnet.png "Añadir cliente a la subred")

7. Puedes ver la configuración actualizada de kea con el nuevo cliente en **Información en servidor ogDHCP** (arriba de todo) y pulsando **Ver informacion**


![Cliente KEA](../../assets/images/screenshots/client_kea.png "Cliente KEA")



## **Crear un Fichero de Arranque PXE**

El objetivo es generar un fichero de arranque personalizado para el cliente `pc11`, utilizando una plantilla PXE definida, la `OgLive`para que arranque por Oglive.


### **Crear el Fichero de Arranque**

1. Ve a la sección **Plantillas PXE** en el menú de **Boot**.
2. Localiza la plantilla `ogLive`que vamos a usar, asignada previamente cuando creamos al cliente **pc11**.
3. Haz clic en el botón del icono de ordenador.

![Plantillas PXE](../../assets/images/screenshots/pxe_templates.menu.png "Plantillas PXE")

4. Busca el cliente **pc11**.

5. Click al botón de sincronizar datos (las dos flechas circulares)

![Netboot avanzado](../../assets/images/screenshots/create_pxe_file.png "Netboot avanzado")

6. Verás que que el icono del ordenador del **pc11** estará en verde. ESo quiere decir que se ha creado el fichero de arranque en **ogboot** correctamente 

![Fichero PXE creado](../../assets/images/screenshots/created_pxe_file.png "Fichero PXE creado")








